@@ -56,15 +56,15 @@ def get_time(text: str, tend_future=True, time_base=None):
     return time_text, time_tuple
 
 
-def get_text(time: Union[datetime, str, int]):
+def get_text(dt: Union[datetime, str, int]):
     now = datetime.now()
-    if isinstance(time, str):
-        time = datetime.strptime(time, TIME_FORMAT)
-    elif isinstance(time, int):
-        time = datetime.fromtimestamp(time)
-    duration = now - time
+    if isinstance(dt, str):
+        dt = datetime.strptime(dt, TIME_FORMAT)
+    elif isinstance(dt, int):
+        dt = datetime.fromtimestamp(dt)
+    duration = now - dt
     today_zero = now - relativedelta(hour=0, minute=0, second=0, microsecond=0)
-    zero_duration = today_zero - time
+    zero_duration = today_zero - dt
     days_span_today_zero = ceil(zero_duration.days + zero_duration.seconds / SECONDS_ONE_DAY)
     reply = []
     if not duration.days:
@@ -77,21 +77,21 @@ def get_text(time: Union[datetime, str, int]):
     else:
         if -2 <= days_span_today_zero <= 2:
             reply.append(around_today(days_span_today_zero))
-        elif time.year != now.year:
-            month_year = now.year - time.year
+        elif dt.year != now.year:
+            month_year = now.year - dt.year
             if month_year:
                 _m = {1: "去", -1: "明"}
-                reply.append(f"{_m.get(month_year, time.year)}年")
-            reply.append(f"{time.month}月")
-            reply.append(f"{time.day}号")
-        elif time.month != now.month:
-            month_span = now.month - time.month
+                reply.append(f"{_m.get(month_year, dt.year)}年")
+            reply.append(f"{dt.month}月")
+            reply.append(f"{dt.day}号")
+        elif dt.month != now.month:
+            month_span = now.month - dt.month
             if month_span:
                 _m = {1: "上个", -1: "下个"}
-                reply.append(f"{_m.get(month_span, time.month)}月")
-            reply.append(f"{time.day}号")
+                reply.append(f"{_m.get(month_span, dt.month)}月")
+            reply.append(f"{dt.day}号")
         else:
-            week_span = time.day - (now.day - now.weekday())
+            week_span = dt.day - (now.day - now.weekday())
             if -7 <= week_span < 0:
                 reply.append(f"上周{WEEK_DAY_DICT.get(week_span + 7 + 1)}")
             elif 7 <= week_span < 14:
@@ -99,25 +99,30 @@ def get_text(time: Union[datetime, str, int]):
             elif 0 <= week_span < 7:
                 reply.append(f"本周{WEEK_DAY_DICT.get(week_span + 1)}")
             else:
-                reply.append(f"{time.day}号")
-    _hour = time.hour
-    if 0 <= _hour < 6:
+                reply.append("本月")
+                reply.append(f"{dt.day}号")
+    _hour = dt.hour
+    if 0 <= _hour < 5:
         reply.append("凌晨")
-    elif 6 <= _hour < 8:
+    elif 5 <= _hour < 8:
         reply.append("早上")
     elif 8 <= _hour < 11:
         reply.append("上午")
     elif 11 <= _hour < 13:
         reply.append("中午")
-    elif 13 <= _hour < 18:
+    elif 13 <= _hour < 17:
         reply.append("下午")
-        _hour -= 12
-    elif 18 <= _hour:
+    elif 17 <= _hour < 19:
+        reply.append("傍晚")
+    elif 19 <= _hour < 22:
         reply.append("晚上")
+    elif 22 <= _hour:
+        reply.append("深夜")
+    if _hour > 12:
         _hour -= 12
     reply.append(f"{_hour}点")
-    if time.minute > 0:
-        reply.append(f"{time.minute}分".zfill(3))
+    if dt.minute > 0:
+        reply.append(f"{dt.minute}分".zfill(3))
     return "".join(reply)
 
 
